==> openshift-model-operator-6.5.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/LoadBalancerStrategyFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public interface LoadBalancerStrategyFluent<A extends LoadBalancerStrategyFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildProviderParameters instead.
   * @return The buildable object.
   */
  @Deprecated
  public ProviderLoadBalancerParameters getProviderParameters();
  public ProviderLoadBalancerParameters buildProviderParameters();
  public A withProviderParameters(ProviderLoadBalancerParameters providerParameters);
  public Boolean hasProviderParameters();
  public LoadBalancerStrategyFluent.ProviderParametersNested<A> withNewProviderParameters();
  public LoadBalancerStrategyFluent.ProviderParametersNested<A> withNewProviderParametersLike(ProviderLoadBalancerParameters item);
  public LoadBalancerStrategyFluent.ProviderParametersNested<A> editProviderParameters();
  public LoadBalancerStrategyFluent.ProviderParametersNested<A> editOrNewProviderParameters();
  public LoadBalancerStrategyFluent.ProviderParametersNested<A> editOrNewProviderParametersLike(ProviderLoadBalancerParameters item);
  public String getScope();
  public A withScope(String scope);
  public Boolean hasScope();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ProviderParametersNested<N> extends Nested<N>,ProviderLoadBalancerParametersFluent<LoadBalancerStrategyFluent.ProviderParametersNested<N>>{
    public N and();
    public N endProviderParameters();
    
  }
  
}

==> openshift-model-operator-6.7.2-sources.jar: io/fabric8/openshift/api/model/operator/v1/LoadBalancerStrategyFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface LoadBalancerStrategyFluent<A extends LoadBalancerStrategyFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildProviderParameters instead.
   * @return The buildable object.
   */
  @Deprecated
  public ProviderLoadBalancerParameters getProviderParameters();
  public ProviderLoadBalancerParameters buildProviderParameters();
  public A withProviderParameters(ProviderLoadBalancerParameters providerParameters);
  public Boolean hasProviderParameters();
  public LoadBalancerStrategyFluent.ProviderParametersNested<A> withNewProviderParameters();
  public LoadBalancerStrategyFluent.ProviderParametersNested<A> withNewProviderParametersLike(ProviderLoadBalancerParameters item);
  public LoadBalancerStrategyFluent.ProviderParametersNested<A> editProviderParameters();
  public LoadBalancerStrategyFluent.ProviderParametersNested<A> editOrNewProviderParameters();
  public LoadBalancerStrategyFluent.ProviderParametersNested<A> editOrNewProviderParametersLike(ProviderLoadBalancerParameters item);
  public String getScope();
  public A withScope(String scope);
  public Boolean hasScope();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ProviderParametersNested<N> extends Nested<N>,ProviderLoadBalancerParametersFluent<LoadBalancerStrategyFluent.ProviderParametersNested<N>>{
    public N and();
    public N endProviderParameters();
    
  }
  
}
